@@ -90,7 +90,7 @@ exiterr (void)
   ORCSerror ();
   dirtempunlink ();
   tempunlink ();
-  _Exit (EXIT_FAILURE);
+  exit_failurefully ();
 }
 
 static void
